# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## 0.10 - 2021-08-04

### Added

- Python 3.8, 3.9 support

## 0.9 - 2018-09-18

### Added

- Python 3.5, 3.6, 3.7 support

### Changed

- Memory files are always stored as binary streams and are encoded/decoded
  based on the mode (r, rb, w, wb)
- Switch to Python's standard zipfile libary

### Removed

- Python 2.5, 2.6 support

## 0.8 - 2015-09-03
